@@ -2,7 +2,7 @@ import asyncio
 from logging import Logger
 from aioprometheus.collectors import Histogram
 from deepmerge import always_merger
-from delphai_utils.logging import default_config, logging
+from delphai_utils.logging import default_config as default_logging_config, logging
 from abc import abstractmethod, abstractproperty
 import faust
 import socket
@@ -174,6 +174,7 @@ class FaustApp():
   app: faust.App
   worker: faust.Worker
   logging_config: Dict
+  faust_config: Dict
   metrics: Service = Service()
 
   async def on_startup_finished(self):
@@ -199,19 +200,25 @@ class FaustApp():
     self.worker._setup_spinner_handler(logger, effective_level)
 
   def __init__(self, id: str, broker: str) -> None:
-    self.app = faust.App(id=id, broker=broker, web_enabled=False)
-    loop = asyncio.get_event_loop()
-    provided_config = {}
     try:
-      provided_config = get_config('logging')
+      self.faust_config = get_config('faust')
+      if self.faust_config is None:
+        self.faust_config = {}
+    except:
+      pass
+    self.app = faust.App(id=id, broker=broker, web_enabled=False, **self.faust_config)
+    loop = asyncio.get_event_loop()
+    provided_logging_config = {}
+    try:
+      provided_logging_config = get_config('logging')
     except Exception:
       pass
-    default_config['disable_existing_loggers'] = False
-    default_config['formatters']['standard']['format'] = '[%(asctime)s] [%(levelname)s] [%(name)s] %(message)s'
-    default_config['loggers']['faust'] = {'level': logging.ERROR}
-    default_config['loggers']['aiokafka'] = {'level': logging.ERROR}
-    default_config['loggers']['mode'] = {'level': logging.ERROR}
-    self.logging_config = always_merger.merge(default_config, provided_config)
+    default_logging_config['disable_existing_loggers'] = False
+    default_logging_config['formatters']['standard']['format'] = '[%(asctime)s] [%(levelname)s] [%(name)s] %(message)s'
+    default_logging_config['loggers']['faust'] = {'level': logging.ERROR}
+    default_logging_config['loggers']['aiokafka'] = {'level': logging.ERROR}
+    default_logging_config['loggers']['mode'] = {'level': logging.ERROR}
+    self.logging_config = always_merger.merge(default_logging_config, provided_logging_config)
     self.worker = faust.Worker(self.app, loop=loop, loglevel=logging.INFO, logging_config=self.logging_config)
     self.worker.on_startup_finished = self.on_startup_finished
     self.worker.on_start = self.on_start
